==> spip_4.0.4.orig.tar.xz: plugins-dist/mots/lang/mots_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=cs
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Důležitá skupina:</b> Doporučujeme, abyste k této skupině vybrali klíčové slovo.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'správci webu',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktoři',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'návštěvníci veřejného webu, když posílají zprávu do diskusní skupiny.',

	// I
	'icone_creation_groupe_mots' => 'Vytvořit novou skupinu slov',
	'icone_creation_mots_cles' => 'Vytvořit nové klíčové slovo',
	'icone_modif_groupe_mots' => 'Změnit skupinu slov',
	'icone_mots_cles' => 'Klíčová slova',
	'icone_supprimer_groupe_mots' => 'Odstranit skupinu',
	'icone_voir_tous_mots_cles' => 'Zobrazit všechna klíčová slova',
	'info_articles_lies_mot' => 'Články spojené s tímto klíčovým slovem',
	'info_changer_nom_groupe' => 'Změnit název skupiny:',
	'info_creation_mots_cles' => 'Vytvořte a nastavte klíčová slova webu',
	'info_dans_groupe' => 'Ve skupině:',
	'info_delet_mots_cles' => 'Zadali jste odstranění klíčového slova
<b>@titre_mot@</b> (@type_mot@). Protože je spojeno s
<b>@texte_lie@</b>, musíte to potvrdit:', # MODIF
	'info_groupe_important' => 'Důležitá skupina',
	'info_mots_cles' => 'Klíčová slova',
	'info_mots_cles_association' => 'Klíčová slova této skupiny lze spojit:',
	'info_oui_suppression_mot_cle' => 'určitě chci toto klíčové slovo odstanit.',
	'info_question_mots_cles' => 'Chcete na vašem webu používat klíčová slova?',
	'info_qui_attribue_mot_cle' => 'Slova z této skupiny smí přiřazovat:',
	'info_retirer_mot' => 'Odstranit toto klíčové slovo',
	'info_retirer_mots' => 'Odstranit všechna klíčová slova',
	'info_rubriques_liees_mot' => 'Sekce spojené s tímto klíčovým slovem',
	'info_selection_un_seul_mot_cle' => 'V této skupině může být najednou vybráno <b>pouze jedno klíčové slovo à</b>.', # MODIF
	'info_supprimer_mot' => 'odstranit slovo',
	'info_titre_mot_cle' => 'Název klíčového slova',
	'info_un_mot' => 'Najednou pouze jedno slovo',
	'item_ajout_mots_cles' => 'Povolit přidání klíčového slova k diskusní skupině',
	'item_non_ajout_mots_cles' => 'Zakázat používání klíčových slov v diskusních skupinách',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nepoužívat rozšířené nastavení klíčových slov',
	'item_non_utiliser_mots_cles' => 'Nepoužívat klíčová slova',
	'item_utiliser_config_groupe_mots_cles' => 'Používat rozšířené nastavení klíčových slov',
	'item_utiliser_mots_cles' => 'Používat klíčová slova',

	// L
	'logo_mot_cle' => 'LOGO KLÍČOVÉHO SLOVA',

	// T
	'texte_config_groupe_mots_cles' => 'Chcete zapnout rozšířené nastavení klíčových slov,
   např. tím, že umožníte výběr jediného slova ve skupině,
   případně zobrazení toho, že skupina je důležitá... ?', # MODIF
	'texte_mots_cles' => 'Klíčová slova umožňují vytvářet tematické odkazy mezi články,
  a to nezávisle na jejich umístění v rámci jednotlivých sekcí.
  Můžete tak obohatit způsob procházení vaším webem, resp. použít tyto možnosti
  k vlastnímu způsobu zobrazení článků v rámci šablon.',
	'texte_mots_cles_dans_forum' => 'Chcete v rámci diskusních skupin veřejného webu povolit používání klíčových slov, jež mohou volit návštěvníci? (Pozor! Správné používání této možnosti je dost komplikované.)', # MODIF
	'texte_nouveau_mot' => 'Nové slovo',
	'titre_config_groupe_mots_cles' => 'Nastavení skupin klíčových slov',
	'titre_gauche_mots_edit' => 'ČÍSLO SLOVA:',
	'titre_mots_cles_dans_forum' => 'Klíčová slova diskusních skupin veřejného webu',
	'titre_mots_tous' => 'Klíčová slova',
	'titre_nouveau_groupe' => 'Nová skupina',
	'titre_page_mots_tous' => 'Klíčová slova'
);

==> spip_4.3.8+dfsg.orig.tar.xz: plugins-dist/mots/lang/mots_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mots?lang_cible=cs
// ** ne pas modifier le fichier **

return [

	// A
	'avis_conseil_selection_mot_cle' => '<b>Důležitá skupina:</b> Doporučujeme, abyste k této skupině vybrali klíčové slovo.',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'správci webu',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'redaktoři',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'návštěvníci veřejného webu, když posílají zprávu do diskusní skupiny.',

	// I
	'icone_creation_groupe_mots' => 'Vytvořit novou skupinu slov',
	'icone_creation_mots_cles' => 'Vytvořit nové klíčové slovo',
	'icone_modif_groupe_mots' => 'Změnit skupinu slov',
	'icone_mots_cles' => 'Klíčová slova',
	'icone_supprimer_groupe_mots' => 'Odstranit skupinu',
	'icone_voir_tous_mots_cles' => 'Zobrazit všechna klíčová slova',
	'info_articles_lies_mot' => 'Články spojené s tímto klíčovým slovem',
	'info_changer_nom_groupe' => 'Změnit název skupiny:',
	'info_creation_mots_cles' => 'Vytvořte a nastavte klíčová slova webu',
	'info_dans_groupe' => 'Ve skupině:',
	'info_delet_mots_cles' => 'Zadali jste odstranění klíčového slova
<b>@titre_mot@</b> (@type_mot@). Protože je spojeno s
<b>@texte_lie@</b>, musíte to potvrdit:', # MODIF
	'info_groupe_important' => 'Důležitá skupina',
	'info_mots_cles' => 'Klíčová slova',
	'info_mots_cles_association' => 'Klíčová slova této skupiny lze spojit:',
	'info_oui_suppression_mot_cle' => 'určitě chci toto klíčové slovo odstanit.',
	'info_question_mots_cles' => 'Chcete na vašem webu používat klíčová slova?',
	'info_qui_attribue_mot_cle' => 'Slova z této skupiny smí přiřazovat:',
	'info_retirer_mot' => 'Odstranit toto klíčové slovo',
	'info_retirer_mots' => 'Odstranit všechna klíčová slova',
	'info_rubriques_liees_mot' => 'Sekce spojené s tímto klíčovým slovem',
	'info_selection_un_seul_mot_cle' => 'V této skupině může být najednou vybráno <b>pouze jedno klíčové slovo à</b>.', # MODIF
	'info_supprimer_mot' => 'odstranit slovo',
	'info_titre_mot_cle' => 'Název klíčového slova',
	'info_un_mot' => 'Najednou pouze jedno slovo',
	'item_ajout_mots_cles' => 'Povolit přidání klíčového slova k diskusní skupině',
	'item_non_ajout_mots_cles' => 'Zakázat používání klíčových slov v diskusních skupinách',
	'item_non_utiliser_config_groupe_mots_cles' => 'Nepoužívat rozšířené nastavení klíčových slov',
	'item_non_utiliser_mots_cles' => 'Nepoužívat klíčová slova',
	'item_utiliser_config_groupe_mots_cles' => 'Používat rozšířené nastavení klíčových slov',
	'item_utiliser_mots_cles' => 'Používat klíčová slova',

	// L
	'logo_mot_cle' => 'LOGO KLÍČOVÉHO SLOVA',

	// T
	'texte_config_groupe_mots_cles' => 'Chcete zapnout rozšířené nastavení klíčových slov,
   např. tím, že umožníte výběr jediného slova ve skupině,
   případně zobrazení toho, že skupina je důležitá... ?', # MODIF
	'texte_mots_cles' => 'Klíčová slova umožňují vytvářet tematické odkazy mezi články,
  a to nezávisle na jejich umístění v rámci jednotlivých sekcí.
  Můžete tak obohatit způsob procházení vaším webem, resp. použít tyto možnosti
  k vlastnímu způsobu zobrazení článků v rámci šablon.',
	'texte_mots_cles_dans_forum' => 'Chcete v rámci diskusních skupin veřejného webu povolit používání klíčových slov, jež mohou volit návštěvníci? (Pozor! Správné používání této možnosti je dost komplikované.)', # MODIF
	'texte_nouveau_mot' => 'Nové slovo',
	'titre_config_groupe_mots_cles' => 'Nastavení skupin klíčových slov',
	'titre_gauche_mots_edit' => 'ČÍSLO SLOVA:',
	'titre_mots_cles_dans_forum' => 'Klíčová slova diskusních skupin veřejného webu',
	'titre_mots_tous' => 'Klíčová slova',
	'titre_nouveau_groupe' => 'Nová skupina',
	'titre_page_mots_tous' => 'Klíčová slova',
];
